@@ -1,6 +1,6 @@
 /* Key bindings and extended commands
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -152,7 +152,7 @@ do_binding_completion (astr as)
       } while (arg != 0);
     }
 
-  minibuf_write ("%s%s%s",
+  minibuf_write ("%s%s%s-",
                  lastflag & (FLAG_SET_UNIARG | FLAG_UNIARG_EMPTY) ? "C-u " : "",
                  astr_cstr (bs),
                  astr_cstr (as));
@@ -182,7 +182,7 @@ get_key_sequence (void)
       Binding p = search_key (root_bindings, keys, 0);
       if (p == NULL || p->func != NULL)
         break;
-      as = astr_cat_char (keyvectostr (keys), '-');
+      as = keyvectostr (keys);
       gl_list_add_last (keys, (void *) do_binding_completion (as));
       astr_delete (as);
     }
@@ -520,7 +520,7 @@ walk_bindings_tree (Binding tree, gl_list_t keys,
           astr bs = chordtostr (p->key);
           for (j = 1; j < gl_list_size (keys); j++)
             {
-              astr_cat (key, (astr) gl_list_get_at (keys, j));
+              astr_cat (key, (castr) gl_list_get_at (keys, j));
               astr_cat_char (key, ' ');
             }
           astr_cat (key, bs);
@@ -532,7 +532,6 @@ walk_bindings_tree (Binding tree, gl_list_t keys,
         walk_bindings_tree (p, keys, process, st);
     }
 
-  astr_delete ((astr) gl_list_get_at (keys, gl_list_size (keys) - 1));
   assert (gl_list_remove_at (keys, gl_list_size (keys) - 1));
 }
 
@@ -541,7 +540,7 @@ walk_bindings (Binding tree, void (*process) (astr key, Binding p, void *st),
                void *st)
 {
   gl_list_t l = gl_list_create_empty (GL_LINKED_LIST,
-                                      NULL, NULL, NULL, true);
+                                      NULL, NULL, (gl_listelement_dispose_fn) astr_delete, true);
   walk_bindings_tree (tree, l, process, st);
   gl_list_free (l);
 }
@@ -572,7 +571,7 @@ Argument is a command name.  If the prefix arg is non-nil, insert the
 message in the buffer.
 +*/
 {
-  const char *name = minibuf_read_function_name ("Where is command: ");
+  char *name = minibuf_read_function_name ("Where is command: ");
   gather_bindings_state g;
 
   ok = leNIL;
@@ -602,7 +601,7 @@ message in the buffer.
         }
     }
 
-  free ((char *) name);
+  free (name);
 }
 END_DEFUN
 
