@@ -1,6 +1,6 @@
 /* Miscellaneous Emacs functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -402,11 +402,7 @@ by 4 each time.
 
   for (;;)
     {
-      size_t key;
-
-      astr_cat_char (as, '-'); /* Add the `-' character. */
-      key = do_binding_completion (as);
-      astr_truncate (as, astr_len (as) - 1); /* Remove the `-' character. */
+      size_t key = do_binding_completion (as);
 
       /* Cancelled. */
       if (key == KBD_CANCEL)
@@ -421,7 +417,11 @@ by 4 each time.
           thisflag &= ~FLAG_UNIARG_EMPTY;
 
           if (key & KBD_META)
-            astr_cat_cstr (as, "ESC");
+            {
+              if (astr_len (as) > 0)
+                astr_cat_char (as, ' ');
+              astr_cat_cstr (as, "ESC");
+            }
 
           astr_afmt (as, " %d", digit);
 
