@@ -55,7 +55,7 @@ add_history_element (History * hp, const char *string)
     hp->elements = gl_list_create_empty (GL_LINKED_LIST,
                                          NULL, NULL, (gl_listelement_dispose_fn) free, true);
   else
-    last = (char *) gl_list_get_at (hp->elements, gl_list_size (hp->elements) - 1);
+    last = (const char *) gl_list_get_at (hp->elements, gl_list_size (hp->elements) - 1);
   if (!last || STRNEQ (last, string))
     gl_list_add_last (hp->elements, xstrdup (string));
 }
@@ -80,7 +80,7 @@ previous_history_element (History * hp)
           if (gl_list_size (hp->elements) > 0)
             {
               hp->sel = gl_list_size (hp->elements) - 1;
-              s = (char *) gl_list_get_at (hp->elements, hp->sel);
+              s = (const char *) gl_list_get_at (hp->elements, hp->sel);
             }
         }
       /* Is there another element? */
@@ -88,7 +88,7 @@ previous_history_element (History * hp)
         {
           /* Select it. */
           hp->sel--;
-          s = (char *) gl_list_get_at (hp->elements, hp->sel);
+          s = (const char *) gl_list_get_at (hp->elements, hp->sel);
         }
     }
 
@@ -106,7 +106,7 @@ next_history_element (History * hp)
       if (hp->sel < (ptrdiff_t) (gl_list_size (hp->elements) - 1))
         {
           hp->sel++;
-          s = (char *) gl_list_get_at (hp->elements, hp->sel);
+          s = (const char *) gl_list_get_at (hp->elements, hp->sel);
         }
       /* No more elements (back to original status). */
       else
