@@ -1,6 +1,6 @@
 /* Lisp parser
 
-   Copyright (c) 2001, 2005, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 2001, 2005, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,10 +19,9 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
@@ -138,6 +137,10 @@ read_token (enum tokenname *tokenid, astr as, size_t * pos)
               astr_truncate (tok, astr_len (tok) -1);
               *tokenid = T_WORD;
               return tok;
+              break;
+
+            default:
+              break;
             }
         }
 
@@ -183,6 +186,9 @@ lisp_read (le * list, astr as, size_t * pos)
           quoted = 0;
           astr_delete (tok);
           return list;
+
+        default:
+          break;
         }
 
       astr_delete (tok);
