@@ -1,6 +1,6 @@
 /* Registers facility functions
 
-   Copyright (c) 2001, 2003, 2004, 2005, 2006, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 2001, 2003, 2004, 2005, 2006, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,13 +19,12 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
@@ -127,7 +126,7 @@ Puts point before and mark after the inserted text.
 END_DEFUN
 
 static void
-write_registers_list (va_list ap GCC_UNUSED)
+write_registers_list (va_list ap _GL_UNUSED_PARAMETER)
 {
   size_t i;
 
