@@ -1,6 +1,6 @@
 /* Window handling functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 1997-2004, 2008-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -162,7 +162,8 @@ Make current window one line bigger.
 {
   Window *wp;
 
-  if (cur_wp == head_wp && cur_wp->next == NULL)
+  if (cur_wp == head_wp && (cur_wp->next == NULL ||
+                            cur_wp->next->fheight < 3))
     return leNIL;
 
   wp = cur_wp->next;
@@ -175,9 +176,6 @@ Make current window one line bigger.
           break;
         }
 
-  if (cur_wp == head_wp && cur_wp->next->fheight < 3)
-    return leNIL;
-
   --wp->fheight;
   --wp->eheight;
   if (wp->topdelta >= wp->eheight)
@@ -217,19 +215,15 @@ END_DEFUN
 Window *
 popup_window (void)
 {
-  if (head_wp->next == NULL)
+  if (head_wp && head_wp->next == NULL)
     {
       /* There is only one window on the screen, so split it. */
       FUNCALL (split_window);
       return cur_wp->next;
     }
 
-  /* Use the window after the current one. */
-  if (cur_wp->next != NULL)
-    return cur_wp->next;
-
-  /* Use the first window. */
-  return head_wp;
+  /* Use the window after the current one, or first window if none. */
+  return cur_wp->next ? cur_wp->next : head_wp;
 }
 
 DEFUN ("delete-other-windows", delete_other_windows)
